# ---------------------------
# RDS
# ---------------------------
# DBサブネットグループの作成
resource "aws_db_subnet_group" "db_subnet_group" {
  name = "${var.name_prefix}${var.env}-${var.db_subnet_group_name}"
  subnet_ids = [
    var.aws_subnet_private_1a_id,
    var.aws_subnet_private_1c_id
  ]
  tags = {
    Name = "${var.name_prefix}${var.env}-${var.db_subnet_group_name}"
  }
}

# RDSインスタンスの作成
resource "aws_db_instance" "rds" {
  identifier = "${var.name_prefix}${var.env}-${var.rds_identifier}"
  # インスタンスクラス、ストレージサイズの指定
  instance_class    = "db.t3.micro"
  allocated_storage = 20
  # DBサブネットグループの指定
  db_subnet_group_name = aws_db_subnet_group.db_subnet_group.name
  # セキュリティグループの指定
  vpc_security_group_ids = [var.rds_sg_id]
  # マルチAZインスタンスの設定
  multi_az = true
  # DBエンジンの指定
  engine         = "mysql"
  engine_version = "8.0.35"
  # DB情報の設定
  db_name  = var.rds_db_name
  username = var.rds_username
  password = var.rds_password
  # 設定変更の即時反映
  apply_immediately = true
  # DB削除時にスナップショットを作成しない
  skip_final_snapshot = true
  # バックアップ保持期間（0に設定すると自動バックアップ無効）
  backup_retention_period = "0"
}
